==> react-image-upload-grid-1.1.0.tgz: package/es/components/SortableList.js <==
// NPM
import React from 'react';
import { SortableContainer } from 'react-sortable-hoc';
import { StyleSheet, css } from 'aphrodite';

// Component
import SortableItem from './SortableItem';
import DropZoneHero from './DropZoneHero';

var SortableList = SortableContainer(function (props) {
  var images = props.images,
      handleDrop = props.handleDrop,
      removeFile = props.removeFile,
      blobs = props.blobs,
      imageClassName = props.imageClassName,
      imageContainerClassName = props.imageContainerClassName;

  return React.createElement(
    'div',
    { className: css(styles.DropZoneGrid) },
    images.length && images.map(function (image, i) {
      var name = image.name,
          lastModified = image.lastModified,
          type = image.type; // uses this as a unique key and id

      var uid = name && lastModified ? name + lastModified : image.id;
      var src = blobs[uid] ? blobs[uid] : image.url; // creates src from image data 
      var many = images.length > 2 ? true : false; // determines the css (size) of dropzones

      return React.createElement(SortableItem, {
        index: i,
        image: image,
        id: uid,
        key: uid,
        src: src,
        imageContainerClassName: imageContainerClassName,
        imageClassName: imageClassName,
        handleDrop: handleDrop,
        removeFile: removeFile,
        many: many,
        isPdf: type === 'application/pdf'
      });
    }),
    React.createElement(DropZoneHero, {
      images: images,
      id: 0,
      addImageClassName: props.addImageClassName,
      blobs: props.blobs,
      saveBlob: props.saveBlob,
      appendFile: props.appendFile,
      removeFile: props.removeFile,
      onSortEnd: props.onSortEnd,
      handleDrop: props.handleDrop,
      addImageText: props.addImageText,
      fileAccept: props.fileAccept
    })
  );
});

var styles = StyleSheet.create({
  DropZoneGrid: {
    display: "flex",
    flexDirection: "row",
    justifyContent: "flex-start",
    alignItems: "center",
    flexWrap: "wrap",
    background: "rbga(248,248,248,0.8)",
    overflowY: "scroll",
    ":-webkit-scrollbar": {
      display: "none",
      width: 0
    }
  }
});

export default SortableList;

==> react-image-upload-grid-1.1.2.tgz: package/es/components/SortableList.js <==
// NPM
import React from 'react';
import { SortableContainer } from 'react-sortable-hoc';
import { StyleSheet, css } from 'aphrodite';

// Component
import SortableItem from './SortableItem';
import DropZoneHero from './DropZoneHero';

var SortableList = SortableContainer(function (props) {
  var images = props.images,
      handleDrop = props.handleDrop,
      removeFile = props.removeFile,
      blobs = props.blobs,
      imageClassName = props.imageClassName,
      imageContainerClassName = props.imageContainerClassName;

  return React.createElement(
    'div',
    { className: css(styles.DropZoneGrid) },
    images.length && images.map(function (image, i) {
      var name = image.name,
          lastModified = image.lastModified,
          type = image.type; // uses this as a unique key and id

      var uid = name && lastModified ? name + lastModified : image.id;
      var src = blobs[uid] ? blobs[uid] : image.url; // creates src from image data 
      var many = images.length > 2 ? true : false; // determines the css (size) of dropzones

      return React.createElement(SortableItem, {
        index: i,
        image: image,
        id: uid,
        key: uid,
        src: src,
        imageContainerClassName: imageContainerClassName,
        imageClassName: imageClassName,
        handleDrop: handleDrop,
        removeFile: removeFile,
        many: many,
        isPdf: type === 'application/pdf'
      });
    }),
    React.createElement(DropZoneHero, {
      images: images,
      id: 0,
      addImageClassName: props.addImageClassName,
      blobs: props.blobs,
      saveBlob: props.saveBlob,
      appendFile: props.appendFile,
      removeFile: props.removeFile,
      onSortEnd: props.onSortEnd,
      handleDrop: props.handleDrop,
      addImageText: props.addImageText,
      fileAccept: props.fileAccept
    })
  );
});

var styles = StyleSheet.create({
  DropZoneGrid: {
    display: "flex",
    flexDirection: "row",
    justifyContent: "center",
    alignItems: "center",
    flexWrap: "wrap",
    background: "rbga(248,248,248,0.8)",
    overflowY: "scroll",
    ":-webkit-scrollbar": {
      display: "none",
      width: 0
    }
  }
});

export default SortableList;
